build_auth_headers

Function build_auth_headers 

pub fn build_auth_headers(token: &String, profile: &Profile) -> HeaderMap
Helper function to build Auth Headers, this is useful for when you still have a valid token